.. This is part of the Photini documentation.
   Copyright (C)  2012-17  Jim Easterbrook.
   See the file ../DOC_LICENSE.txt for copying condidions.

Change Log
==========

.. literalinclude:: ../../../CHANGELOG.txt
   :language: none
